@@ -1,67 +1,15 @@
 package Game::Battleship;
+our $AUTHORITY = 'cpan:GENE';
 # ABSTRACT: "You sunk my battleship!"
 
 use strict;
 use warnings;
 
-our $VERSION = '0.0503';
+our $VERSION = '0.0504';
 
 use Carp;
 use Game::Battleship::Player;
 
-=head1 NAME
-
-Game::Battleship - "You sunk my battleship!"
-
-=head1 SYNOPSIS
-
-  use Game::Battleship;
-  my $g = Game::Battleship->new(qw( Gene Aaron ));
-  $g->add_player('Alisa');
-  my $winner = $g->play();
-  print $winner->name(), " wins!\n";
-
-=head1 DESCRIPTION
-
-A C<Game::Battleship> object represents a battleship game between
-players.  Each has a fleet of vessels and operates with a pair of
-playing grids  One is for their own fleet and one for where the
-enemy has been seen.
-
-Everything is an object with default but mutable attributes.  This way
-games can have two or more players each with a single fleet of custom
-vessels.  These vessels are pretty simple and standard right now...
-
-A game can be played with the handy C<play()> method or for finer
-control, use individual methods of the C<Game::Battleship::*>
-modules.  See the distribution test script for working code examples.
-
-=head1 METHODS
-
-=head2 B<new()>
-
-  $g = Game::Battleship->new;
-  $g = Game::Battleship->new(
-      $name_1,
-      $player_object,
-      { name => $name_2,
-        fleet => \@fleet,
-        dimensions => [ $width, $height ], },
-  );
-
-Construct a new C<Game::Battleship> object.
-
-The players can be given as scalars, a C<Game::Battleship::Player>
-object or as a hash reference containing meaningful object attributes.
-
-If not given explicitly, 'player_1' and 'player_2' are used as the
-player names and two 10x10 grids with 5 predetermined ships are setup
-by default for each.
-
-See L<Game::Battleship::Player> for details on the default and custom
-settings.
-
-=cut
 
 sub new {
     my $class = shift;
@@ -78,41 +26,6 @@ sub _setup {
     $self->add_player($_) for @players;
 }
 
-=head2 B<game_type()>
-
-=cut
-
-sub game_type {
-    my $self = shift;
-    $self->{type} = shift if @_;
-    return $self->{type};
-}
-
-=head2 B<add_player()>
-
-  $g->add_player;
-  $g->add_player($name);
-  $g->add_player({
-      name => $name,
-      fleet => \@fleet,
-      dimensions => [$w, $h],
-  });
-  $g->add_player($player, $number);
-
-Add a player to the existing game.
-
-This method can accept either nothing, a string, a
-C<Game::Battleship::Player> object or a hash reference
-of meaningful C<Game::Battleship::Player> attributes.
-
-This method also accepts an optional numeric second argument that is
-the player number.
-
-If this number is not provided, the least whole number that is not
-represented in the player IDs is used.  If a player already exists
-with that number, a warning is emitted and the player is not added..
-
-=cut
 
 sub add_player {
     my ($self, $player, $i) = @_;
@@ -171,17 +84,6 @@ sub add_player {
     return $self->{$who};
 }
 
-=head2 B<player()>
-
-  $player_obj = $g->player($name);
-  $player_obj = $g->player($number);
-  $player_obj = $g->player($key);
-
-Return the C<Game::Battle::Player> object that matches the given
-name, key or number (where the key is C</player_\d+/> and the number
-is just the numeric part of the key).
-
-=cut
 
 sub player {
     my ($self, $name) = @_;
@@ -206,23 +108,9 @@ sub player {
     return $player;
 }
 
-=head2 B<players()>
-
-=cut
 
 sub players { return shift->{players} }
 
-=head2 B<play()>
-
-  $winner = $g->play;
-
-Take a turn for each player, striking all the opponents, until there
-is only one player left alive.
-
-Return the C<Game::Battleship::Player> object that is the game
-winner.
-
-=cut
 
 sub play {
     my ($self, %args) = @_;
@@ -263,54 +151,136 @@ sub _get_coordinate {
 
     my ($x, $y);
 
-    # Are we using a specific game type?
-    if ($self->{type}) {
-warn "Unimlemented feature.  RTFM please.\n";
-#        if ($self->{type} eq 'text') {}
-#        elsif ($self->{type} eq 'cgi') {}
-    }
-#    else {
-        # No?  Okay, just return random coordinates, then.
-        ($x, $y) = (
-            int 1 + rand $player->{grid}->{dimension}[0],
-            int 1 + rand $player->{grid}->{dimension}[1]
-        );
-#    }
+    # Return random coordinates...
+    ($x, $y) = (
+        int 1 + rand $player->{grid}->{dimension}[0],
+        int 1 + rand $player->{grid}->{dimension}[1]
+    );
 
 #    warn "$x, $y\n";
     return $x, $y;
 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Game::Battleship - "You sunk my battleship!"
+
+=head1 VERSION
+
+version 0.0504
+
+=head1 SYNOPSIS
+
+  use Game::Battleship;
+  my $g = Game::Battleship->new(qw( Gene Aaron ));
+  $g->add_player('Alisa');
+  my $winner = $g->play();
+  print $winner->name(), " wins!\n";
+
+=head1 DESCRIPTION
+
+A C<Game::Battleship> object represents a battleship game between
+players.  Each has a fleet of vessels and operates with a pair of
+playing grids.  One grid is for their own fleet and the other for
+the seen enemy positions.
+
+Everything is an object with default but mutable attributes.  This way
+games can have two or more players each with a single fleet of custom
+vessels.
+
+A game can be played with the handy C<play()> method or for finer
+control, use individual methods of the C<Game::Battleship::*>
+modules.  See the distribution test script for working code examples.
+
+=head1 NAME
+
+Game::Battleship - "You sunk my battleship!"
+
+=head1 METHODS
+
+=head2 B<new()>
+
+  $g = Game::Battleship->new;
+  $g = Game::Battleship->new($name);
+  $g = Game::Battleship->new($player_object);
+  $g = Game::Battleship->new(
+      { name => $name,
+        fleet => \@fleet,
+        dimensions => [ $width, $height ] },
+  );
+
+Construct a new C<Game::Battleship> object.
+
+The players can be given as strings, C<Game::Battleship::Player>
+objects or as hash references containing player attributes.
+
+If not given explicitly, 'player_1' and 'player_2' are used as the
+player names with two 10 x 10 grids and 5 predetermined ships are setup
+for each.
+
+See L<Game::Battleship::Player> for details on the default and custom
+settings.
+
+=head2 B<add_player()>
+
+  $g->add_player;
+  $g->add_player($name);
+  $g->add_player({
+      name => $name,
+      fleet => \@fleet,
+      dimensions => [$w, $h],
+  });
+  $g->add_player($player, $number);
+
+Add a player to the existing game.
+
+This method can accept either nothing, a string, a
+C<Game::Battleship::Player> object or a hash reference
+of meaningful C<Game::Battleship::Player> attributes.
+
+This method also accepts an optional numeric second argument that is
+the player number.
+
+If this number is not provided, the least whole number that is not
+represented in the player IDs is used.  If a player already exists
+with that number, a warning is emitted and the player is not added.
+
+=head2 B<player()>
+
+  $player_obj = $g->player($name);
+  $player_obj = $g->player($number);
+  $player_obj = $g->player($key);
+
+Return the C<Game::Battle::Player> object that matches the given
+name, key or number (where the key is C</player_\d+/> and the number
+is just the numeric part of the key).
+
+=head2 B<players()>
+
+=head2 B<play()>
+
+  $winner = $g->play;
+
+Take a turn for each player, striking all the opponents, until there
+is only one player left alive.
+
+Return the C<Game::Battleship::Player> object that is the game
+winner.
+
 =head1 TO DO
 
 Implement the "number of shots" measure.  This may be based on life
 remaining, shots taken, hits made or ships sunk (etc?).
 
-Make the C<play> method output the player grids for each turn.
-
-Keep pending games and personal scores in a couple handy text files.
-
-Make an eg/simple program with text and then one with colored text.
-
-Implement game type and then allow network play.
-
-Make an eg/cgi program both as text and with Imager.
-
-Make standalone GUI programs too...
-
-Enhance to include these features:
-sonar imaging from your submarine.
-2 Exocet missiles fired from your aircraft carrier.
-1 Tomahawk missile fired from your battleship.
-2 Apache missile fired from your destroyer.
-2 torpedoes fired from your submarine.
-2 recon airplanes for surveillance.
-
-This all just means implementing weapon and recon classes with name,
-quantity and footprint.
+Enhance weaponry and sensing.
 
 =head1 SEE ALSO
 
@@ -322,14 +292,13 @@ quantity and footprint.
 
 =head1 AUTHOR
 
-Gene Boggs E<lt>gene@cpan.orgE<gt>
+Gene Boggs <gene@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2003-2012, Gene Boggs
+This software is copyright (c) 2015 by Gene Boggs.
 
-=head1 LICENSE
-
-This software is free to use for non-commercial, personal purposes.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
